# pylaunch

Simple library for working with the DIAL Protocol.

DIAL -- "DIscovery And Launch" is a simple protocol that second-screen devices can use to discover and launch apps on first-screen devices.

[Dial Protocol Specification](https://sites.google.com/a/dial-multiscreen.org/dial/dial-protocol-specification "DIAL Protocol Specifcation")